@@ -152,6 +152,7 @@ typedef enum {
 	CD_SENSOR_KIND_SPECTRO_SCAN,
 	CD_SENSOR_KIND_I1_PRO,
 	CD_SENSOR_KIND_COLORIMTRE_HCFR,
+	CD_SENSOR_KIND_I1_DISPLAY3,	/* Since: 0.1.14 */
 	CD_SENSOR_KIND_LAST
 } CdSensorKind;
 
@@ -215,6 +216,8 @@ typedef enum {
 #define CD_PROFILE_METADATA_DATA_SOURCE		"DATA_source"
 #define CD_PROFILE_METADATA_DATA_SOURCE_EDID	"edid"
 #define CD_PROFILE_METADATA_DATA_SOURCE_CALIB	"calib"
+#define CD_PROFILE_METADATA_DATA_SOURCE_STANDARD "standard"		/* Since: 0.1.14 */
+#define CD_PROFILE_METADATA_DATA_SOURCE_TEST	"test"			/* Since: 0.1.14 */
 #define CD_PROFILE_METADATA_MAPPING_FORMAT	"MAPPING_format"
 #define CD_PROFILE_METADATA_MAPPING_QUALIFIER	"MAPPING_qualifier"
 
